//  gmodconfig - a Gnome based kernel module configuration tool
//  http://gmodconfig.sourceforge.net/
//  Copyright (C) 2003 Cyril Bortolato
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//  testcontrol.cpp: unit test program that loads gmodconfig's Bonobo control
//--------------------------------------------------------------------------//

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <iostream>
#include <bonobo.h>
#include <gnome.h>

using namespace std;

static void
showModule( GtkWidget* w, const char* modName )
{
    BonoboControlFrame* cf = bonobo_widget_get_control_frame(BONOBO_WIDGET(w));
    Bonobo_PropertyBag pb =
        bonobo_control_frame_get_control_property_bag( cf, CORBA_OBJECT_NIL );
    bonobo_pbclient_set_string( pb, "showModule", modName, CORBA_OBJECT_NIL );
    bonobo_object_release_unref( pb, NULL );
}

int main(int argc, char ** argv)
{
    if ( argc != 2 )
    {
        cout << "Usage: " << argv[0] << " <module name>" << endl;
        return 1;
    }

    bind_textdomain_codeset( GETTEXT_PACKAGE, "UTF-8" );

    // Init Gnome and Bonobo
    gnome_program_init( "testcontrol", "",
                        LIBGNOMEUI_MODULE, argc, argv, NULL );

    if ( !bonobo_init( &argc, argv ) )
        return 1;
    bonobo_activate();

    // Create the app and a VBox
    GtkWidget* app = gnome_app_new( "testcontrol", "testcontrol" );
    gtk_widget_show( app );
    gtk_signal_connect( GTK_OBJECT( app ), "delete_event",
                        GTK_SIGNAL_FUNC( gtk_main_quit ), NULL );

    GtkWidget* vbox = gtk_vbox_new( FALSE, 0 );
    gtk_widget_show( vbox );
    gnome_app_set_contents( GNOME_APP(app), vbox );

    // Load up the control and add it to the vbox
    const char* oafId = "OAFIID:GNOME_Linux_ModuleManager";
    GtkWidget* ctrl = bonobo_widget_new_control( oafId, CORBA_OBJECT_NIL );
    if ( !ctrl )
        return 1;
    gtk_widget_show( ctrl );
    gtk_box_pack_start( GTK_BOX(vbox), ctrl, TRUE, TRUE, 5 );

    // Show the module passed as parameter
    showModule( ctrl, argv[1] );

    gtk_main();
    return 0;
}

