//  gmodconfig - a Gnome based kernel module configuration tool
//  http://gmodconfig.sourceforge.net/
//  Copyright (C) 2003 Cyril Bortolato
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//  testmodinfo.cpp: unit test program for the module info XML reader/writer
//--------------------------------------------------------------------------//

#include <libgnomevfs/gnome-vfs.h>
#include <iostream>
#include <fstream>
#include "modinforeader.h"
#include "modinfowriter.h"
#include "moduletypes.h"
#include <unistd.h>

using namespace gmodcfg;

static Module*
readModuleInfos( const string& xmlfile )
{
    ModuleInfoReader reader;
    std::ifstream ifs( xmlfile.c_str() );
    return reader.ReadFromStream( ifs );
}

static void
writeModuleInfos( const Module* mod, const string& xmlfile )
{
    ModuleInfoWriter writer;
    std::ofstream ofs( xmlfile.c_str() );
    writer.WriteToStream( mod, ofs );
}

int main()
{
    gnome_vfs_init();

    Module* mod1 = readModuleInfos( "ov511.xml" );
    writeModuleInfos( mod1, "tmp1.xml" );
    delete mod1;

    Module* mod2 = readModuleInfos( "tmp1.xml" );
    writeModuleInfos( mod2, "tmp2.xml" );
    delete mod2;

    int rc = system("diff tmp1.xml tmp2.xml");

    unlink("tmp1.xml");
    unlink("tmp2.xml");

    return rc != 0;
}

